<template>
    <div class="history">
        <div class="history__header">
            <span>История игр</span>
            <span @click="$root.$emit('closeJackpotHistory')"><i class="fa fa-times" aria-hidden="true"></i></span>
        </div>
        <div class="history__body">
            <table class="table">
                <thead class="table__head">
                    <tr class="table__head-row">
                        <td class="table__head-item">
                            Игра
                        </td>
                        <td class="table__head-item">
                            Пользователь
                        </td>
                        <td class="table__head-item">
                            Билет
                        </td>
                        <td class="table__head-item">
                            Выигрыш
                        </td>
                    </tr>
                </thead>
                <tbody class="table__body" id="jackpot__history">
                    <tr class="table__body-row" v-for="game in games">
                        <td class="table__body-item table__padding">
                            #{{ game.id }}
                        </td>
                        <td class="table__body-item" style="display: flex;align-items: center;">
                            <img 
                                :src="game.photo_200"
                                style="width: 32px;border-radius: 4px;margin-right: 10px;"
                            >
                            <span 
                                @click="$root.$emit('showProfile', game.user_id)" 
                                style="cursor: pointer"
                            >
                                {{ game.username }}
                            </span>
                        </td>
                        <td class="table__body-item">
                            <i class="fa-solid fa-ticket"></i>&nbsp;{{ game.ticket }}
                        </td>
                        <td class="table__body-item" style="font-weight: 400">
                            {{ parseFloat(game.bank).toFixed(2) }}
                        </td>
                    </tr>
                </tbody>
            </table>
        </div>
    </div>
</template>

<script>
export default {
    data() {
        return {
            games: [],
        }
    },
    mounted() {
        this.init()
    },
    methods: {
        init() {
            this.$root.axios.post('/jackpot/history')
            .then(response => {
                const {data} = response
                this.games = data
            })
        }
    },
    sockets: {
        jackpot(data) {
            if(data.type == 'result') {
                if(this.games.length >= 10) {
                    this.games.pop()
                }

                this.games.unshift({
                    id: data.game_id,
                    photo_200: data.photo_200,
                    username: data.username,
                    ticket: data.ticket,
                    bank: data.amount
                })
            }
        }
    }
}
</script>

<style scoped>
.history {
    margin-top: 16px;
    padding: 32px 57px;
    background: #fff;
    border-radius: 0 0 8px 8px;
}

.history__header {
    display: flex;
    justify-content: space-between;
    flex-direction: row
}

span > .fa-times {
    color: #c3bdde;
    cursor: pointer;
    font-size: 24px
}

.table {
    margin: 5px 0!important;
}
</style>